# PyRolL Elastic mill spring

PyRolL plugin calculating the influence of the elastic mill spring.

For the docs, see [here](docs/docs.pdf).

This project is licensed under the [BSD-3-Clause license](LICENSE).

The package is available via [PyPi](https://pypi.org/project/elastic-mill-spring/) and can be installed with

    pip install pyroll-elastic-mill-spring


